"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.completeSelfCheck = exports.ImageParseMethod = exports.HTTPFormData = exports.HTTPFormDataEntry = exports.getFilenameFromUrl = void 0;
var file_system_1 = require("tns-core-modules/file-system");
function getFilenameFromUrl(url) {
    var slashPos = url.lastIndexOf("/") + 1;
    var questionMarkPos = url.lastIndexOf("?");
    var actualFileName;
    if (questionMarkPos !== -1) {
        actualFileName = url.substring(slashPos, questionMarkPos);
    }
    else {
        actualFileName = url.substring(slashPos);
    }
    var result = file_system_1.path.join(file_system_1.knownFolders.documents().path, actualFileName);
    return result;
}
exports.getFilenameFromUrl = getFilenameFromUrl;
var HTTPFormDataEntry = (function () {
    function HTTPFormDataEntry(data, name, type) {
        this.data = data;
        this.name = name;
        this.type = type;
    }
    return HTTPFormDataEntry;
}());
exports.HTTPFormDataEntry = HTTPFormDataEntry;
var HTTPFormData = (function () {
    function HTTPFormData() {
        this.values = new Map();
    }
    HTTPFormData.prototype.append = function (name, value) {
        if (!this.values.has(name)) {
            this.values.set(name, new Array());
        }
        var values = this.values.get(name);
        values.push(value);
        this.values.set(name, values);
    };
    HTTPFormData.prototype.delete = function (name) {
        this.values.delete(name);
    };
    HTTPFormData.prototype.get = function (name) {
        if (this.has(name)) {
            return this.values.get(name)[0];
        }
        return null;
    };
    HTTPFormData.prototype.getAll = function (name) {
        var value = this.values.get(name);
        if (value) {
            return value;
        }
        return [];
    };
    HTTPFormData.prototype.has = function (name) {
        return this.values.has(name);
    };
    HTTPFormData.prototype.set = function (name, value) {
        var values = new Array();
        values.push(value);
        this.values.set(name, values);
    };
    HTTPFormData.prototype.forEach = function (callbackfn, thisArg) {
        var _this = this;
        this.values.forEach(function (mapVal, mapKey) {
            mapVal.forEach(function (formVal) {
                callbackfn(formVal, mapKey, _this);
            });
        }, thisArg);
    };
    return HTTPFormData;
}());
exports.HTTPFormData = HTTPFormData;
var ImageParseMethod;
(function (ImageParseMethod) {
    ImageParseMethod[ImageParseMethod["NEVER"] = 0] = "NEVER";
    ImageParseMethod[ImageParseMethod["CONTENTTYPE"] = 1] = "CONTENTTYPE";
    ImageParseMethod[ImageParseMethod["ALWAYS"] = 2] = "ALWAYS";
})(ImageParseMethod = exports.ImageParseMethod || (exports.ImageParseMethod = {}));
function completeSelfCheck(options) {
    var response = new Blob(["{ \"SelfCheck\": \"OK!\" }"], {
        type: "application/json",
    });
    return Promise.resolve({
        content: {
            raw: response,
            toArrayBuffer: function () { return Blob.InternalAccessor.getBuffer(response).buffer.slice(0); },
            toString: function (encoding) {
                return "{ \"SelfCheck\": \"OK!\" }";
            },
            toJSON: function (encoding) {
                return {
                    "SelfCheck": "OK!",
                };
            },
            toImage: function () {
                throw new Error("toImage Not implemented for self-check.");
            },
            toFile: function (destinationFilePath) {
                throw new Error("toFile Not implemented for self-check.");
            }
        },
        statusCode: 200,
        headers: options.headers
    });
}
exports.completeSelfCheck = completeSelfCheck;
//# sourceMappingURL=http.common.js.map